==> haskell-securemem-0.1.9-23-i686.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
key: securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: b794206c4979d66a34cacb4bf5e5db43
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF ghc-prim-0.5.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.9-24-i686.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-FBW2jhbDv3PKBgqrsNUU9E
key: securemem-0.1.9-FBW2jhbDv3PKBgqrsNUU9E
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: 949579cc23bbf5275489d83ad1aed6d4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-FBW2jhbDv3PKBgqrsNUU9E
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ ghc-prim-0.5.1.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=66cafb37fc02a74908fd731801b55463
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
